AcceptAuth class

Inheritance
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

AcceptAuth({required String authMethod, String? token, String? info, String? mechanism})
AcceptAuth.fromJson(Map<String, dynamic> json)
factory

Properties

authMethod String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
info String?
getter/setter pair
mechanism String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String?
getter/setter pair
type String
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

hash(String hashName) → Hash
Creates a combined hash code for a number of objects.
override