Contact class

Inheritance
Implemented types
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

Contact({required String id, required String ownerUserId, String? avatarUrl, DateTime? createdAt, String? nickname, String? note})
Contact.fromJson(Map<String, dynamic> json)
factory

Properties

avatarUrl String?
getter/setter pairinherited
createdAt DateTime?
getter/setter pairinherited
displayName String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pairinherited
idKey String
no setteroverride
name String?
getter/setter pairinherited
nickname String?
getter/setter pairinherited
note String?
getter/setter pair
ownerUserId String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tableName() String
override
toJson() Map<String, dynamic>
toSqliteMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

fields List<String>
no setter
stableName String
getter/setter pair

Static Methods

fromSqlite(List<Map<String, Object?>> list) List<Contact>