CreateChannel class

Inheritance
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

CreateChannel({required String channelType, required bool one2one, List<String>? subscribeUserIds, String? name, String? description, String? parentId, String? parentType, String? folder, String? nickname, String? avatarUrl, int? readMessageMaxRole, int? sendMessageMaxRole})
CreateChannel.fromJson(Map<String, dynamic> json)
factory

Properties

avatarUrl String?
getter/setter pair
channelType String
getter/setter pair
description String?
getter/setter pair
folder String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
getter/setter pair
nickname String?
getter/setter pair
one2one bool
getter/setter pair
parentId String?
getter/setter pair
parentType String?
getter/setter pair
readMessageMaxRole int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendMessageMaxRole int?
getter/setter pair
subscribeUserIds List<String>?
getter/setter pair
type String
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

eventType → const String