Event class
- Annotations
-
- @JsonSerializable.new(fieldRename: FieldRename.snake)
Constructors
Properties
- createTimestamp ↔ int
-
getter/setter pair
- data ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadata
↔ Map<
String, String> ? -
getter/setter pair
-
payload
↔ Map<
String, dynamic> ? -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ String
-
getter/setter pair
Methods
-
eachMeta(
dynamic h(String key, String val)) → dynamic -
getMeta(
String key) → String -
hasMeta(
String key, String val) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
packPayload(
) → dynamic -
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
-
unpackPayload(
) → dynamic -
withMeta(
String key, String val) → dynamic
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited