FileCacher class

Constructors

FileCacher({required FileManager fileManager})

Properties

fileManager FileManager
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cachedFile(String id, {ImageSize size = ImageSize.md}) Future<File?>
cachedFileInfo(String id) Future<FileInfo?>
cacheFile(String id, {ImageSize size = ImageSize.md, void receiveCallback(int, int)?}) Future<File?>
cacheFileInfo(String id) Future<FileInfo?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
syncedFile(String id, {ImageSize size = ImageSize.md}) File?
syncedFileInfo(String id) FileInfo?
toString() String
A string representation of this object.
inherited
uncacheFileInfo(String id) Future<bool>

Operators

operator ==(Object other) bool
The equality operator.
inherited