FileInfo class

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

FileInfo({required String id, required String mimeType, String? md5sum, String? filename, int? size, ImageInfo? imageInfo, VideoInfo? videoInfo, String? accessUrl})
FileInfo.fromJson(Map<String, dynamic> json)
factory

Properties

accessUrl String?
getter/setter pair
filename String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
imageInfo ImageInfo?
getter/setter pair
md5sum String?
getter/setter pair
mimeType String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int?
getter/setter pair
videoInfo VideoInfo?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited