Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createFileId()
→ Future<String?>
-
-
download(String path, String savePath, {void receiveCallback(int, int)?, Map<String, dynamic>? data, HandleError? handleError, ImageSize imageSize = ImageSize.md})
→ Future
-
-
getAccessUrl(String id)
→ Future<String?>
-
-
getFileInfo(String id)
→ Future<FileInfo?>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
upload(String id, dynamic file, {dynamic onSent(int sent, int total)?, dynamic onFail(dynamic)?})
→ Future<FileInfo?>
-