FileUploader class

Constructors

FileUploader({required FileManager fileManager})

Properties

fileManager FileManager
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
upload(List<XFile> files, {dynamic onSent(XFile file, int sent, int total)?, dynamic onFail(XFile file, int code, String info)?, dynamic onSucess(FileInfo file)?}) Future<List<FileInfo?>>

Operators

operator ==(Object other) bool
The equality operator.
inherited