HttpFileManager class

Inheritance

Constructors

HttpFileManager({required DioHelper helper})

Properties

hashCode int
The hash code for this object.
no setterinherited
helper DioHelper
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createFileId() Future<String?>
override
download(String path, String savePath, {void receiveCallback(int, int)?, Map<String, dynamic>? data, HandleError? handleError, ImageSize imageSize = ImageSize.md}) Future
override
getAccessUrl(String id) Future<String?>
override
getFileInfo(String id) Future<FileInfo?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
upload(String id, dynamic file, {dynamic onSent(int sent, int total)?, dynamic onFail(dynamic)?}) Future<FileInfo?>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited