LikeMessage class

Inheritance
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

LikeMessage({required String messageId, required int amount})
LikeMessage.like({required String messageId})
LikeMessage.uncertain({required String messageId})
LikeMessage.unlike({required String messageId})

Properties

amount int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
messageId String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

eventType → const String