Message class

Inheritance
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

Message({required String id, required String channelId, required String creatorId, String? text, List<FileInfo>? media, FileInfo? audio, List<FileInfo>? attachment, MessageArticle? article, String? referMessageId, String? prevId, DateTime? createdAt, DateTime? updatedAt})
Message.fromJson(Map<String, dynamic> json)
factory

Properties

article MessageArticle?
getter/setter pair
attachment List<FileInfo>?
getter/setter pair
audio FileInfo?
getter/setter pair
channelId String
getter/setter pair
createdAt DateTime?
getter/setter pair
creatorId String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
idKey String
no setterinherited
media List<FileInfo>?
getter/setter pair
prevId String?
getter/setter pair
referMessageId String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
getter/setter pair
updatedAt DateTime?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tableName() String
override
toJson() Map<String, dynamic>
toSqliteMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromSqlite(List<Map<String, dynamic>> data) List<Message>

Constants

fields → const List<String>
stableName → const String