MessageTag class

Inheritance
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

MessageTag({required String id, required String channelId, required String messageId, required String creatorUserId, required String tag, DateTime? createdAt, DateTime? updatedAt})
MessageTag.fromJson(Map<String, dynamic> json)
factory

Properties

channelId String
getter/setter pair
createdAt DateTime?
getter/setter pair
creatorUserId String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
idKey String
no setterinherited
messageId String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String
getter/setter pair
updatedAt DateTime?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tableName() String
override
toJson() Map<String, dynamic>
toSqliteMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fields → const List<String>
stableName → const String