Miaoba class

Inheritance

Constructors

Miaoba({required Transport transport, required Encoding encoding, Future onConnected()?, String? cryptoMethod, String? compressMethod, String? scramMethod, String? token, String? username, String? password})

Properties

clientKeyPair ↔ AsymmetricKeyPair<PublicKey, PrivateKey>
getter/setter pair
compressMethod String?
final
cryptoMethod String?
final
encoding Encoding
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
lastCode ErrorCode
no setterinherited
lastError String
no setterinherited
onConnected Future Function()?
getter/setter pairoverride-setter
opt ServerOptions
getter/setter pair
password String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scramMethod String?
final
state ConnectState
no setteroverride
token String?
final
transport Transport
getter/setter pair
username String?
final

Methods

addEventListner(EventHandler handler) → dynamic
inherited
addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
callHandler(Event e) → dynamic
inherited
decode(Packet data) Event
inherited
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
encode(Event data) Packet
inherited
encodePayload(Payload payload) Packet
inherited
handle(Packet payload, Transport t) Future
listen() Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeEventListner(EventHandler handler) → dynamic
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
send(Event event) Future<bool>
override
setLastError(ErrorCode code, String error) → dynamic
inherited
stop() Future
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited