ModelAction class
- Annotations
-
- @JsonSerializable.new(fieldRename: FieldRename.snake)
Constructors
-
ModelAction({required String model, required String action, List<
String> ? recordIds, Map<String, dynamic> ? data}) -
ModelAction.fromJson(Map<
String, dynamic> json) -
factory
Properties
- action ↔ String
-
getter/setter pair
-
data
↔ Map<
String, dynamic> ? -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- model ↔ String
-
getter/setter pair
-
recordIds
↔ List<
String> ? -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited