NamedAvatar class

Implementers
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

NamedAvatar({required String id, String? name, String? nickname, String? avatarUrl, DateTime? createdAt})

Properties

avatarUrl String?
getter/setter pair
createdAt DateTime?
getter/setter pair
displayName String
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
name String?
getter/setter pair
nickname String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

fields List<String>
no setter