ServerOptions class

Inheritance
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

ServerOptions({required List<String> acceptAuth, required List<String> acceptCompress, required List<String> acceptCrypto, required DateTime time})
ServerOptions.fromJson(Map<String, dynamic> json)
factory

Properties

acceptAuth List<String>
getter/setter pair
acceptCompress List<String>
getter/setter pair
acceptCrypto List<String>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time DateTime
getter/setter pair
type String
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

eventType → const String