Sqlite class

Constructors

Sqlite()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(SqliteModel model) Future<void>
getdb() Future<Database>
insert<T extends SqliteModel>(List<T> models) Future<int>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(SqliteModel model) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited