Subscriber class

Inheritance
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

Subscriber({required String id, required String userId, required String channelId, int role = SubscribeRole.roleAny, bool online = false, int unreadMessages = 0, DateTime? lastReadMessageAt, String? lastReadMessageId, String? avatarUrl, String? nickname, DateTime? createdAt})
Subscriber.fromJson(Map<String, dynamic> json)
factory

Properties

avatarUrl String?
getter/setter pairinherited
channelId String
getter/setter pair
createdAt DateTime?
getter/setter pairinherited
displayName String
no setterinherited
folder String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pairinherited
invitedBy String?
getter/setter pair
lastReadMessageAt DateTime?
getter/setter pair
lastReadMessageId String?
getter/setter pair
name String?
getter/setter pairinherited
nickname String?
getter/setter pairinherited
online bool
getter/setter pair
role int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unreadMessages int
getter/setter pair
userId String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

fields List<String>
no setter
stableName String
getter/setter pair

Static Methods

fromSqlite(List<Map<String, dynamic>> data) List<Subscriber>