SyncDB class

Constructors

SyncDB({required Database db})

Properties

db ↔ Database
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyEvent(String userId, ModelChanged event) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

alignModel(Map<String, dynamic> data) → dynamic
fixData(Map<String, dynamic> data) Map<String, dynamic>

Constants

persistances → const List<String>