TagMessage class

Inheritance
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

TagMessage({required String messageId, required String tag, bool untag = false})

Properties

hashCode int
The hash code for this object.
no setterinherited
messageId String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String
getter/setter pair
type String
no setteroverride
untag bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

eventType → const String