Transport class abstract

Inheritance
Implementers

Constructors

Transport()

Properties

handlers List<TransportEventHandler>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
layers List<Layer>
getter/setter pair
onDone ← dynamic Function(Transport)?
no getter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state TransportConnectState
no setter

Methods

addEventHandler(TransportEventHandler handler) → dynamic
addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
close() Future
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
handle(Packet packet, Transport sc) Future
listen() Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
pushLayer(Layer l) → dynamic
removeEventHandler(TransportEventHandler handler) → dynamic
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
send(Packet packet) Future
sendPacket(Packet packet) Future<bool>
setState(TransportConnectState state) → dynamic
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited