UpdateMessage class

Inheritance
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

UpdateMessage({required String id, String? text, List<FileInfo>? media, MessageArticle? article, FileInfo? audio, List<FileInfo>? attachment})
UpdateMessage.fromJson(Map<String, dynamic> json)
factory

Properties

article MessageArticle?
getter/setter pair
attachment List<FileInfo>?
getter/setter pair
audio FileInfo?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
media List<FileInfo>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
getter/setter pair
type String
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

eventType → const String