User class

Inheritance
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

User({required String id, required String? name, required String countryCode, DateTime? createdAt, String? avatarUrl, String? nickname, String? emailAddr, String? phoneNumber, DateTime? updatedAt})
User.fromJson(Map<String, dynamic> json)
factory

Properties

avatarUrl String?
getter/setter pairinherited
countryCode String
getter/setter pair
createdAt DateTime?
getter/setter pairinherited
displayName String
no setterinherited
emailAddr String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pairinherited
name String
getter/setter pairinherited-setteroverride-getter
nickname String?
getter/setter pairinherited
phoneNumber String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedAt DateTime?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

fields List<String>
no setter
stableName String
getter/setter pair