UserManager class abstract

Implementers

Constructors

UserManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

changePasswordByOldPassword(String password, String oldPassword, {HandleError? onError}) Future<bool>
changePasswordByVerifyCode(String password, ContactType contactType, String contact, String verifyCode, {HandleError? onError}) Future<bool>
fetchUsers({String? keyword, List<String>? userIds, int? limit}) Future<List<User>?>
login(String account, AccountType accountType, PassType passType, String passcode, {HandleError? onError}) Future<LoginUser?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendVerifyCode(ContactType contactType, String contact) Future<bool>
signout() Future<bool>
signup(String username, String countryCode, String contact, ContactType contactType, String verifyCode, String password, {HandleError? onError}) Future<LoginUser?>
toString() String
A string representation of this object.
inherited
updateContact({required ContactType type, required String contact, required String verifyCode, HandleError? onError}) Future<bool>
updateInfo({String? nickname, String? avatarUrl, HandleError? onError}) Future<bool>
verifyAccount(String account, {HandleError? onError}) Future<AccountType?>

Operators

operator ==(Object other) bool
The equality operator.
inherited