VideoInfo class

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake)

Constructors

VideoInfo({FileInfo? thumbnailInfo, String? artist, String? title, int? duration, required int width, required int height})
VideoInfo.fromJson(Map<String, dynamic> json)
factory

Properties

artist String?
getter/setter pair
duration int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thumbnailInfo FileInfo?
getter/setter pair
title String?
getter/setter pair
width int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited