AcceptAuth class
Constructors
- AcceptAuth({required String authMethod, String? token, String? info, String? mechanism})
-
AcceptAuth.fromJson(Map<
String, dynamic> json) -
factory
Properties
- authMethod ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- info ↔ String?
-
getter/setter pair
- mechanism ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- token ↔ String?
-
getter/setter pair
- type → String
-
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
Constants
- eventType → const String
- methodScram → const String
- methodToken → const String
- scramSha1 → const String
- scramSha1PLUS → const String
- scramSha224 → const String
- scramSha224PLUS → const String
- scramSha256 → const String
- scramSha256PLUS → const String
- scramSha384 → const String
- scramSha384PLUS → const String
- scramSha512 → const String
- scramSha512PLUS → const String
- scramSha3224 → const String
- scramSha3224PLUS → const String
- scramSha3256 → const String
- scramSha3256PLUS → const String
- scramSha3384 → const String
- scramSha3384PLUS → const String
- scramSha3512 → const String
- scramSha3512PLUS → const String