AcceptCompress class
Constructors
- AcceptCompress({required String compressMethod, String? order, int? litWidth, int? level})
-
AcceptCompress.fromJson(Map<
String, dynamic> json) -
factory
Properties
- compressMethod ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- level ↔ int?
-
getter/setter pair
- litWidth ↔ int?
-
getter/setter pair
- order ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited