Country class
- Annotations
-
- @JsonSerializable.new(fieldRename: FieldRename.snake)
Constructors
-
Country({required String name, required String cca2, required String cca3, required String fips, required String ioc, required String fifa, required String emoji, required int code, required int currency, required int capital, required int domain, required int region, List<
String> ? subdivisionCodes, List<int> ? callingCode}) -
const
-
Country.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
callingCode
→ List<
int> ? -
final
- capital → int
-
final
- cca2 → String
-
final
- cca3 → String
-
final
- code → int
-
final
- currency → int
-
final
- domain → int
-
final
- emoji → String
-
final
- fifa → String
-
final
- fips → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- ioc → String
-
final
- name → String
-
final
- region → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subdivisionCodes
→ List<
String> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited