DioHelper class
Properties
-
dio
→ Dio
-
no setter
-
domain
↔ String
-
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
onError
↔ dynamic Function(dynamic)?
-
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
token
↔ String?
-
getter/setter pair
Methods
-
delete(String path, {Map<String, dynamic>? data, Options? options, HandleError? showError})
→ Future
-
-
dioUpload({Duration? receiveTimeout, Duration? connectTimeout, Duration? sendTimeout})
→ Dio
-
-
download(String path, String savePath, {void receiveCallback(int, int)?, Map<String, dynamic>? data, Options? options, HandleError? showError})
→ Future
-
-
get(String path, {Map<String, dynamic>? data, Options? options, HandleError? onError})
→ Future
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
post(String path, {Object? data, Options? options, HandleError? showError})
→ Future
-
-
put(String path, {Map<String, dynamic>? data, Options? options, HandleError? handleError})
→ Future
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
upload(String path, dynamic data, {dynamic onSent(int sent, int total)?, String method = "post", HandleError? handleError})
→ Future
-