Mockingbird class
- Inheritance
-
- Object
- ChangeNotifier
- Mockingbird
- Implemented types
Properties
- db ↔ Database
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- lang → String
-
no setter
- lastCode → ErrorCode
-
no setter
- lastError → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ MockingbirdState
-
getter/setter pair
- userId ↔ String
-
getter/setter pair
Methods
-
addEventListener(
HandleEvent e) → dynamic -
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
getLastActiveAt(
String model, {String? channelId}) → Future< String> -
handle(
Event event) → dynamic -
override
-
initialize(
{required dynamic userId, required Protocol proto, required dynamic clientId, required Database db}) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeEventListener(
HandleEvent e) → dynamic -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
send(
Event event, {bool? waitResult, Duration? timeout, bool syncing = true}) → Future< Event?> -
setLanguage(
String lang) → Future< bool> -
stop(
) → dynamic -
syncChannel(
) → dynamic -
syncContact(
) → dynamic -
syncMessage(
String channelId) → dynamic -
syncMessageLike(
String channelId) → dynamic -
syncMessageTag(
String channelId) → dynamic -
syncModels(
) → Future< bool> -
toString(
) → String -
A string representation of this object.
inherited
-
valid(
{bool syncing = false}) → dynamic
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → Mockingbird
-
final
-
models
↔ List<
String> -
getter/setter pair