Protocol class abstract
- Inheritance
-
- Object
- ChangeNotifier
- Protocol
- Implementers
Properties
- encoding ↔ Encoding
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- lastCode → ErrorCode
-
no setter
- lastError → String
-
no setter
- onConnected ← Future Function()
-
no getter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → ConnectState
-
no setter
Methods
-
addEventListner(
EventHandler handler) → dynamic -
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
callHandler(
Event e) → dynamic -
decode(
Packet data) → Event -
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
encode(
Event data) → Packet -
encodePayload(
Payload payload) → Packet -
listen(
) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeEventListner(
EventHandler handler) → dynamic -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
send(
Event event) → dynamic -
setLastError(
ErrorCode code, String error) → dynamic -
stop(
) → Future -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited