RequestIdEventHandler class
- Implemented types
Constructors
- RequestIdEventHandler(dynamic handleFunc(Event e), {required String requestId})
Properties
- handleFunc ↔ dynamic Function(Event e)
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- requestId ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
handle(
Event e) → dynamic -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited